nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Gpr10

Struct Gpr10 

#[repr(transparent)]
pub struct Gpr10(pub u32);
SRC General Purpose Register 10

Tuple Fields

0: u32

Implementations

Source

impl Gpr10

pub const fn persist_redundant_boot(&self) -> u8

This field identifies which image must be used - 0/1/2/3

pub const fn set_persist_redundant_boot(&mut self, val: u8)

This field identifies which image must be used - 0/1/2/3

pub const fn persist_secondary_boot(&self) -> bool

This bit identifies which image must be used - primary and secondary

pub const fn set_persist_secondary_boot(&mut self, val: bool)

This bit identifies which image must be used - primary and secondary