#[repr(transparent)]pub struct Scr(pub u32);Expand description
SRC Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Scr
impl Scr
Sourcepub const fn lockup_rst(&self) -> LockupRst
pub const fn lockup_rst(&self) -> LockupRst
lockup reset enable bit
Sourcepub const fn set_lockup_rst(&mut self, val: LockupRst)
pub const fn set_lockup_rst(&mut self, val: LockupRst)
lockup reset enable bit
Sourcepub const fn mask_wdog_rst(&self) -> MaskWdogRst
pub const fn mask_wdog_rst(&self) -> MaskWdogRst
Mask wdog_rst_b source
Sourcepub const fn set_mask_wdog_rst(&mut self, val: MaskWdogRst)
pub const fn set_mask_wdog_rst(&mut self, val: MaskWdogRst)
Mask wdog_rst_b source
Sourcepub const fn set_core0_rst(&mut self, val: Core0Rst)
pub const fn set_core0_rst(&mut self, val: Core0Rst)
Software reset for core0 only
Sourcepub const fn core0_dbg_rst(&self) -> Core0DbgRst
pub const fn core0_dbg_rst(&self) -> Core0DbgRst
Software reset for core0 debug only
Sourcepub const fn set_core0_dbg_rst(&mut self, val: Core0DbgRst)
pub const fn set_core0_dbg_rst(&mut self, val: Core0DbgRst)
Software reset for core0 debug only
Sourcepub const fn dbg_rst_msk_pg(&self) -> DbgRstMskPg
pub const fn dbg_rst_msk_pg(&self) -> DbgRstMskPg
Do not assert debug resets after power gating event of core
Sourcepub const fn set_dbg_rst_msk_pg(&mut self, val: DbgRstMskPg)
pub const fn set_dbg_rst_msk_pg(&mut self, val: DbgRstMskPg)
Do not assert debug resets after power gating event of core
Sourcepub const fn mask_wdog3_rst(&self) -> MaskWdog3Rst
pub const fn mask_wdog3_rst(&self) -> MaskWdog3Rst
Mask wdog3_rst_b source
Sourcepub const fn set_mask_wdog3_rst(&mut self, val: MaskWdog3Rst)
pub const fn set_mask_wdog3_rst(&mut self, val: MaskWdog3Rst)
Mask wdog3_rst_b source