nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Srsr

Struct Srsr 

#[repr(transparent)]
pub struct Srsr(pub u32);
SRC Reset Status Register

Tuple Fields

0: u32

Implementations

Source

impl Srsr

pub const fn ipp_reset_b(&self) -> IppResetB

Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)

pub const fn set_ipp_reset_b(&mut self, val: IppResetB)

Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)

pub const fn lockup(&self) -> Lockup

Indicates a reset has been caused by CPU lockup.

pub const fn set_lockup(&mut self, val: Lockup)

Indicates a reset has been caused by CPU lockup.

pub const fn csu_reset_b(&self) -> CsuResetB

Indicates whether the reset was the result of the csu_reset_b input.

pub const fn set_csu_reset_b(&mut self, val: CsuResetB)

Indicates whether the reset was the result of the csu_reset_b input.

pub const fn ipp_user_reset_b(&self) -> IppUserResetB

Indicates whether the reset was the result of the ipp_user_reset_b qualified reset.

pub const fn set_ipp_user_reset_b(&mut self, val: IppUserResetB)

Indicates whether the reset was the result of the ipp_user_reset_b qualified reset.

pub const fn wdog_rst_b(&self) -> WdogRstB

IC Watchdog Time-out reset

pub const fn set_wdog_rst_b(&mut self, val: WdogRstB)

IC Watchdog Time-out reset

pub const fn jtag_rst_b(&self) -> JtagRstB

HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z reset from JTAG.

pub const fn set_jtag_rst_b(&mut self, val: JtagRstB)

HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z reset from JTAG.

pub const fn jtag_sw_rst(&self) -> JtagSwRst

JTAG software reset

pub const fn set_jtag_sw_rst(&mut self, val: JtagSwRst)

JTAG software reset

pub const fn wdog3_rst_b(&self) -> Wdog3RstB

IC Watchdog3 Time-out reset

pub const fn set_wdog3_rst_b(&mut self, val: Wdog3RstB)

IC Watchdog3 Time-out reset

pub const fn tempsense_rst_b(&self) -> TempsenseRstB

Temper Sensor software reset

pub const fn set_tempsense_rst_b(&mut self, val: TempsenseRstB)

Temper Sensor software reset