#[repr(transparent)]pub struct Gpr10(pub u32);Expand description
SRC General Purpose Register 10
Tuple Fields
0: u32Implementations
Sourceimpl Gpr10
impl Gpr10
Sourcepub const fn persist_redundant_boot(&self) -> u8
pub const fn persist_redundant_boot(&self) -> u8
This field identifies which image must be used - 0/1/2/3
Sourcepub const fn set_persist_redundant_boot(&mut self, val: u8)
pub const fn set_persist_redundant_boot(&mut self, val: u8)
This field identifies which image must be used - 0/1/2/3
Sourcepub const fn persist_secondary_boot(&self) -> bool
pub const fn persist_secondary_boot(&self) -> bool
This bit identifies which image must be used - primary and secondary
Sourcepub const fn set_persist_secondary_boot(&mut self, val: bool)
pub const fn set_persist_secondary_boot(&mut self, val: bool)
This bit identifies which image must be used - primary and secondary